summaryrefslogtreecommitdiffstats
path: root/Source/cmLocalUnixMakefileGenerator2.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmLocalUnixMakefileGenerator2.cxx')
-rw-r--r--Source/cmLocalUnixMakefileGenerator2.cxx4
1 files changed, 3 insertions, 1 deletions
diff --git a/Source/cmLocalUnixMakefileGenerator2.cxx b/Source/cmLocalUnixMakefileGenerator2.cxx
index 124d6ba..9de8f4d 100644
--- a/Source/cmLocalUnixMakefileGenerator2.cxx
+++ b/Source/cmLocalUnixMakefileGenerator2.cxx
@@ -789,8 +789,10 @@ cmLocalUnixMakefileGenerator2
std::vector<std::string> commands;
std::vector<std::string> depends;
- // Utility targets store their rules in post-build commands.
+ // Utility targets store their rules in pre- and post-build commands.
+ this->AppendCustomDepends(depends, target.GetPreBuildCommands());
this->AppendCustomDepends(depends, target.GetPostBuildCommands());
+ this->AppendCustomCommands(commands, target.GetPreBuildCommands());
this->AppendCustomCommands(commands, target.GetPostBuildCommands());
// Add dependencies on targets that must be built first.